import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');
//The geoMercator() function in d3.js is used 
//to draw The spherical Mercator projection.
const projection = geoMercator()
  .translate([-800, 590]) // poistion
  .scale([850]); // zoom

// given a JSON geometry object, to generates an SVG path
const pathGenerator = geoPath().projection(projection);

//Array of ten categorical colors which is returned as RGB hexadecimal strings. 
const colorScale = scaleOrdinal(schemeCategory10);

//loading data
json('https://gist.githubusercontent.com/codingcooper/7c04a14bff65ed89d0856f3ab94a3ddb/raw/d4cb89f409cb5c3a67d6559eb017ea5e8e394a1a/IndiaMap.json'
).then((data) => {
  //extracting states data
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
  
countryShapes.features.shift()

	//Renders the path to a Canvas by appending path 
  //generated by pathgenerator to svg
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

  //Rendering text with state names in the middle of state
  svg
    .selectAll('text')
    .data(countryShapes.features)
    .enter()
    .append('text')
    .text((d) => d.properties.NAME_1)
    .attr('x', d=>  pathGenerator.centroid(d)[0]   )
    .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
    .attr("font-size", "7px")
 });